@@ -311,6 +311,17 @@ void run_actions_normalize_tests() {
     /* app_context: */                   u"abcệ"
   );
 
+  test_actions_normalize(
+    "One backspace to delete last NFD character (#15487)",
+    /* app context pre transform: */     u"abcê", // NFC
+    /* cached context post transform: */ u"abce",
+    /* cached context post transform: */ nullptr,
+    /* action del, output: */            1, U"",  // NFD input;  delete 1: \u0302
+    // ---- results ----
+    /* action del, output: */            1, U"e",             // NFC output; delete 1: e
+    /* app_context: */                   u"abce"
+  );
+
   test_actions_normalize(
     "One backspace for NFD converts into one char in NFC (ê) and recombine",
     /* app context pre transform: */     u"abcê",
