@@ -1,7 +1,7 @@
 # shellcheck shell=bash
 # no hashbang for .inc.sh
 
-KEYMAN_MIN_VERSION_EMSCRIPTEN=3.1.58
+. "$KEYMAN_ROOT/resources/build/minimum-versions.inc.sh"
 
 #
 # We don't want to rely on emcc being on the path, because Emscripten puts far
@@ -10,7 +10,7 @@ KEYMAN_MIN_VERSION_EMSCRIPTEN=3.1.58
 # The following comment suggests that we don't need emcc on the path.
 # https://github.com/emscripten-core/emscripten/issues/4848#issuecomment-1097357775
 #
-# So we try and locate  in common locations ourselves. The search pattern
+# So we try and locate emcc in common locations ourselves. The search pattern
 # is:
 #
 # 1. Look for $EMSCRIPTEN_BASE (our primary emscripten variable), which should
@@ -27,11 +27,11 @@ locate_emscripten() {
   fi
   if [[ -z ${EMSCRIPTEN_BASE+x} ]]; then
     if [[ -z ${EMCC+x} ]]; then
-      local EMCC=`which ${EMCC_EXECUTABLE}`
-      [[ -z $EMCC ]] && builder_die "locate_emscripten: Could not locate emscripten (emcc) on the path or with \$EMCC or \$EMSCRIPTEN_BASE"
+      local EMCC=$(which ${EMCC_EXECUTABLE})
+      [[ -z $EMCC ]] && builder_die "locate_emscripten: Could not locate emscripten (${EMCC_EXECUTABLE}) on the path or with \$EMCC or \$EMSCRIPTEN_BASE"
     fi
-    [[ -f $EMCC && ! -x $EMCC ]] && builder_die "locate_emscripten: Variable EMCC ($EMCC) points to emcc but it is not executable"
-    [[ -x $EMCC ]] || builder_die "locate_emscripten: Variable EMCC ($EMCC) does not point to a valid executable emcc"
+    [[ -f $EMCC && ! -x $EMCC ]] && builder_die "locate_emscripten: Variable EMCC ($EMCC) points to ${EMCC_EXECUTABLE} but it is not executable"
+    [[ -x $EMCC ]] || builder_die "locate_emscripten: Variable EMCC ($EMCC) does not point to a valid executable ${EMCC_EXECUTABLE}"
     EMSCRIPTEN_BASE="$(dirname "$EMCC")"
   fi
   [[ -f ${EMSCRIPTEN_BASE}/${EMCC_EXECUTABLE} && ! -x ${EMSCRIPTEN_BASE}/${EMCC_EXECUTABLE} ]] && builder_die "locate_emscripten: Variable EMSCRIPTEN_BASE ($EMSCRIPTEN_BASE) contains ${EMCC_EXECUTABLE} but it is not executable"
@@ -41,7 +41,7 @@ locate_emscripten() {
 }
 
 # Ensure that we use correct version of emsdk on build agents.
-# For developers, define KEYMAN_USE_SDK to do this on your
+# For developers, define KEYMAN_USE_EMSDK to do this on your
 # build machine.
 verify_emscripten_version() {
   if [[ "$VERSION_ENVIRONMENT" != local || ! -z "${KEYMAN_USE_EMSDK+x}" ]]; then
@@ -66,8 +66,20 @@ _select_emscripten_version_with_emsdk() {
   fi
 
   export EMSDK_KEEP_DOWNLOADS=1
-  git pull
-  ./emsdk install "$KEYMAN_MIN_VERSION_EMSCRIPTEN"
-  ./emsdk activate "$KEYMAN_MIN_VERSION_EMSCRIPTEN"
+  if builder_try_offline; then
+    if [[ ! -f ./emsdk_env.sh ]]; then
+      builder_die "emsdk_env.sh not found - emsdk not installed?"
+    fi
+    . ./emsdk_env.sh
+    if ! emcc --version | grep -q "$KEYMAN_MIN_VERSION_EMSCRIPTEN"; then
+      builder_die "Wrong emsdk version installed"
+    fi
+  else
+    git pull
+    ./emsdk install "$KEYMAN_MIN_VERSION_EMSCRIPTEN"
+    ./emsdk activate "$KEYMAN_MIN_VERSION_EMSCRIPTEN"
+    cd upstream/emscripten
+    npm install
+  fi
   popd > /dev/null
 }
